@@ -17,7 +17,7 @@ die "Usage: device_scalar_n_list.pl NETWORK_INTERFACE_NAME"
 
 
 my $udev = Udev::FFI->new() or
-    die "Can't create udev context: $@.\n";
+    die "Can't create Udev::FFI object: $@.\n";
 
 my $device = $udev->new_device_from_syspath('/sys/class/net/'.$ARGV[0]);
 if($device) {
