@@ -186,4 +186,76 @@ sub DESTROY {
 
 
 
-1;
\ No newline at end of file
+1;
+
+
+
+__END__
+
+
+
+=head1 NAME
+
+Udev::FFI::Enumerate
+
+=head1 SYNOPSIS
+
+    use Udev::FFI;
+    
+    my $udev = Udev::FFI->new() or
+        die "Can't create Udev::FFI object: $@";
+    
+    my $enumerate = $udev->new_enumerate() or
+        die "Can't create enumerate context: $@";
+    
+    $enumerate->add_match_subsystem('usb');
+    $enumerate->add_match_sysattr('idVendor'); #devices with VID
+    
+    $enumerate->scan_devices();
+    
+    my @devices = $enumerate->get_list_entries();
+    for(@devices) {
+        my $device = $udev->new_device_from_syspath($_);
+    
+        if(defined $device) {
+            print "DEVICE: ".$device->get_sysname()."\n";
+            print "VID: ".$device->get_sysattr_value('idVendor')."\n";
+            print "PID: ".$device->get_sysattr_value('idProduct')."\n\n";
+        }
+    }
+
+=head1 METHODS
+
+=head2 add_match_subsystem ( SUBSYSTEM )
+
+=head2 add_nomatch_subsystem ( SUBSYSTEM )
+
+=head2 add_match_sysattr ( SYSATTR [, VALUE] )
+
+=head2 add_nomatch_sysattr ( SYSATTR [, VALUE] )
+
+=head2 add_match_property ( PROPERTY [, VALUE] )
+
+=head2 add_match_sysname ( SYSNAME )
+
+=head2 add_match_tag ( TAG )
+
+=head2 add_match_parent ( PARENT )
+
+=head2 add_match_is_initialized ()
+
+=head2 add_syspath ( SYSPATH )
+
+=head2 scan_devices ()
+
+=head2 scan_subsystems ()
+
+=head2 get_list_entries ()
+
+=head2 get_udev ()
+
+=head1 SEE ALSO
+
+L<Udev::FFI> main Udev::FFI documentation
+
+=cut
\ No newline at end of file
